@@ -8,7 +8,8 @@ function (kern, params) {
   kern$whiteVariance <- 0
   for ( i in seq(along=kern$comp) ) {
     endVal <- endVal+kern$comp[[i]]$nParams
-    kern$comp[[i]] <- kernExpandParam(kern$comp[[i]], params[startVal:endVal])
+    kern$comp[[i]] <- kernExpandParam(kern$comp[[i]], params[seq(startVal,len=kern$comp[[i]]$nParams)])
+    ## Used to be: kern$comp[[i]] <- kernExpandParam(kern$comp[[i]], params[startVal:endVal])
     startVal <- endVal+1
     if ( "white" %in% kern$comp[[i]]$type ) {
       kern$whiteVariance <- kern$whiteVariance+kern$comp[[i]]$variance
